﻿using Syncfusion.WinForms.DataGrid;
using Syncfusion.WinForms.DataGrid.Enums;
using Syncfusion.WinForms.DataGrid.Events;
using Syncfusion.WinForms.DataGrid.Helpers;
using System.Linq;
using System.Windows.Forms;

namespace DataGrid_GettingStartedDemo
{
    public partial class Form1 : Form
    {
        OrderInfoCollection orderInfoCollection = new OrderInfoCollection();
        public Form1()
        {
            InitializeComponent();
            sfDataGrid1.DataSource = orderInfoCollection.Orders;
            CreateUnboundRow();
        }

        private void CreateUnboundRow()
        {
            this.sfDataGrid1.QueryUnboundRowInfo += sfDataGrid1_QueryUnboundRow;
            this.sfDataGrid1.TableControl.Scroll += OnDataGridScroll;
            this.sfDataGrid1.CurrentCellEndEdit += sfDataGrid1_CurrentCellEndEdit;
            this.sfDataGrid1.UnboundRows.Add(new GridUnboundRow() { Position = VerticalPosition.Bottom, ShowBelowSummary = false });
        }

        private void OnDataGridScroll(object sender, ScrollEventArgs e)
        {
            if (sfDataGrid1.TableControl.ScrollRows.LastBodyVisibleLineIndex == this.sfDataGrid1.ResolveUnboundRowToRowIndex(sfDataGrid1.UnboundRows[0]))
            {
                var rowIndex = this.sfDataGrid1.ResolveUnboundRowToRowIndex(sfDataGrid1.UnboundRows[0]);
                var column = this.sfDataGrid1.Columns["Price"];
                this.sfDataGrid1.InValidateUnboundRow(sfDataGrid1.UnboundRows[0], true);
                this.InvalidateRowRectangle(rowIndex, false);
            }
        }

        private void sfDataGrid1_QueryUnboundRow(object sender, QueryUnboundRowInfoArgs e)
        {
            if (e.Column.MappingName == "Price")
            {
                e.Value = orderInfoCollection.Orders.Sum(items => items.Price).ToString("0.00");
            }
            e.Handled = true;
        }


        void sfDataGrid1_CurrentCellEndEdit(object sender, CurrentCellEndEditEventArgs e)
        {
            var rowIndex = this.sfDataGrid1.ResolveUnboundRowToRowIndex(sfDataGrid1.UnboundRows[0]);
            this.sfDataGrid1.InValidateUnboundRow(sfDataGrid1.UnboundRows[0], true);
            this.InvalidateRowRectangle(rowIndex, false);

        }

        internal void InvalidateRowRectangle(int rowIndex, bool isClipped)
        {
            var rowRectangle = this.sfDataGrid1.TableControl.GetRowRectangle(rowIndex, isClipped);
            this.sfDataGrid1.TableControl.Invalidate(rowRectangle);
        }

        private void RemoveBtn_Click(object sender, System.EventArgs e)
        {
            orderInfoCollection.RemoveItem();
            this.sfDataGrid1.InValidateUnboundRow(sfDataGrid1.UnboundRows[0], true);
            this.InvalidateRowRectangle(this.sfDataGrid1.ResolveUnboundRowToRowIndex(sfDataGrid1.UnboundRows[0]), false);
        }

        private void AddBtn_Click(object sender, System.EventArgs e)
        {
            orderInfoCollection.AddItem();
            this.sfDataGrid1.InValidateUnboundRow(sfDataGrid1.UnboundRows[0], true);
            this.InvalidateRowRectangle(this.sfDataGrid1.ResolveUnboundRowToRowIndex(sfDataGrid1.UnboundRows[0]), false);
        }
    }
}

